@@ -19,6 +19,7 @@
 
 #include <cliser/clt/NetworkThread.hpp>
 
+#include "utils.hpp"
 #include "PlaybackThread.hpp"
 
 
@@ -311,6 +312,8 @@ public:
 	ting::u8 volume;
 	float freq;
 
+	E_Timbre timbre;
+
 	MusicActionMessage(MainThread* clientMainThread) :
 			mt(clientMainThread)
 	{
