@@ -771,3 +771,38 @@ SampledInstrument::ADSRParams SawtoothInstrument::GetADSRParams(){
 	};
 	return adsr;
 }
+
+
+
+//static
+Ref<aumiks::Sample> ThereminInstrument::GenerateSample(){
+	float cosines[] = {
+		- 0.0443446,  - 0.0107732
+	};
+
+	float sines[] = {
+		- 0.9653393 , - 0.1647417
+	};
+
+	ting::StaticBuffer<float, sizeof(cosines) / sizeof(cosines[0])> c, s;
+	ASSERT(c.SizeInBytes() == sizeof(cosines))
+	ASSERT(s.SizeInBytes() == sizeof(sines))
+	memcpy(c.Begin(), cosines, c.SizeInBytes());
+	memcpy(s.Begin(), sines, s.SizeInBytes());
+
+	//sampling rate 44100Hz, sound base freq is 25Hz
+	return Sample::GenerateFromFourier(c, s, 44100 / 25, 25);
+}
+
+
+
+SampledInstrument::ADSRParams ThereminInstrument::GetADSRParams(){
+	ADSRParams adsr = {
+		20, //attack
+		0, //decay
+		1, //sustainLevel
+		30 //release
+	};
+	return adsr;
+}
+
